import styled from 'styled-components';
import { startCase, camelCase } from 'lodash-es';
import * as FeatherIcons from 'react-icons/fi';
import { FeatherIconNames, featherIconNames } from './featherIcon';
import theme from '../../../../theme';
export type IconNames = FeatherIconNames;
export const iconNames = [...featherIconNames] as string[];

interface IconProps {
  size?: number;
  color?: string;
  backgroundColor?: string;
  name?: IconNames;
}

export default function Icon(props: IconProps) {
  const { size, color, name, backgroundColor, ...remain } = props;
  const iconNameByPascalCase = startCase(camelCase(name)).replace(/ /g, '');
  const FeatherIcon = FeatherIcons[`Fi${iconNameByPascalCase}`];

  if (!FeatherIcon) return null;
  return (
    <Box size={size} backgroundColor={backgroundColor}>
      <FeatherIcon size={size} color={color} />
    </Box>
  );
}

Icon.defaultProps = {
  name: null,
  size: 24,
  color: theme.colors.black,
  backgroundColor: 'transparent',
};

const Box = styled.div<IconProps>`
  display: block;
  width: ${props => props.size}px;
  height: ${props => props.size}px;
  min-width: ${props => props.size}px;
  min-height: ${props => props.size}px;
  max-width: ${props => props.size}px;
  max-height: ${props => props.size}px;
  line-height: 0;
  vertical-align: bottom;
  background: ${({ backgroundColor }) => backgroundColor};
`;
