import { ReactNode, useState } from 'react';
import styled from 'styled-components';
import { motion } from 'framer-motion';
import Title from '../../atoms/Title/Title';
import Button from '../Button/Button';

interface DrawerProps {
  onClose?: any;
  title?: string;
  openButton?: React.ReactNode;
  children?: React.ReactNode;
}

export default function Drawer(props: DrawerProps) {
  const { title, onClose, openButton, children, ...remain } = props;
  const [isOpen, setIsOpen] = useState(false);
  const [isAnimating, setIsAnimating] = useState(false);
  const toggleDrawer = () => setIsOpen(state => !state);

  const handleAnimationComplete = () => {
    setIsAnimating(false);
  };

  const handleClose = () => {
    if (isOpen && !isAnimating) {
      setIsAnimating(true);
      onClose();
    }
  };

  const variants = {
    open: { x: 0 },
    closed: { x: '100%' },
  };

  return (
    <>
      <OpenButtonArea onClick={toggleDrawer}>{openButton}</OpenButtonArea>
      {isOpen && (
        <DrawerBox initial="closed" animate="open" exit="closed" variants={variants} onAnimationComplete={handleAnimationComplete} onClick={handleClose}>
          <DrawerContent>
            <DrawerHeaderArea>
              <Title content={title} />
              <Button onClick={toggleDrawer} content="" icon="x" size="sm" iconPosition="right" />
            </DrawerHeaderArea>
            <DrawerBodyArea>{children}</DrawerBodyArea>
          </DrawerContent>
          <DrawerOverlay onClick={() => setIsOpen(false)} exit={{ opacity: 0 }} transition={{ duration: 1 }} />
        </DrawerBox>
      )}
    </>
  );
}

Drawer.defaultProps = {
  openButton: <Button buttonType="ghost" />,
  title: 'Drawer 제목입니다 Drawer 제목입니다 Drawer 제목입니다 Drawer 제목입니다 Drawer 제목입니다',
  children: 'Drawer 내부 컴포넌트를 설정해주세요',
};

const OpenButtonArea = styled(motion.div)``;

const DrawerBox = styled(motion.div)`
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 999;
  background-color: #fff;
  overflow-x: hidden;
  overflow-y: auto;
`;

const DrawerContent = styled(motion.div)`
  display: flex;
  flex-direction: column;
  position: relative;
  padding: 16px;
  background-color: #fff;
  z-index: 999;
  width: 100%;
  height: 100%;
`;

const DrawerHeaderArea = styled(motion.div)`
  display: flex;
  width: 100%;
  justify-content: space-between;
`;

const DrawerBodyArea = styled(motion.div)`
  display: flex;
  width: 100%;
  flex: 1;
  margin-top: 24px;
`;

const DrawerOverlay = styled(motion.div)`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.1);
`;
