import styled from 'styled-components';
import { motion } from 'framer-motion';
import theme from '../../../../theme';
import { Stack } from '../../../layout';

interface RadioInputProps {
  defaultColor?: string;
  activeColor?: string;
  label?: { color?: string; text?: string };
  isActive?: boolean;
}

export default function RadioInput(props: RadioInputProps) {
  const { isActive, label, defaultColor, activeColor } = props;

  return (
    <Box>
      <Stack gap={8}>
        <RadioIcon isActive={isActive} defaultColor={defaultColor} activeColor={activeColor} />
        {label.text && (
          <LabelStyled isActive={isActive} defaultColor={defaultColor} activeColor={activeColor}>
            {label.text}
          </LabelStyled>
        )}
      </Stack>
      <VisuallyHiddenRadio type="radio" checked={isActive} />
    </Box>
  );
}

RadioInput.defaultProps = {
  isActive: true,
  defaultColor: theme.colors.gray300,
  activeColor: theme.colors.black,
  label: {
    text: 'Text',
  },
};

const Box = styled(motion.div)`
  display: flex;
  position: relative;
  font-family: ${theme.fontFamily.normal};
`;

const RadioIcon = styled(motion.div)<RadioInputProps>`
  width: 24px;
  height: 24px;
  position: relative;
  border: 2px solid ${({ isActive, activeColor, defaultColor }) => (isActive ? activeColor : defaultColor)};
  border-radius: 50%;

  :after {
    content: '';
    display: ${({ isActive }) => (isActive ? 'block' : 'none')};
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    border-radius: 50%;
    background: ${({ isActive, activeColor }) => (isActive ? activeColor : 'none')};
    width: 12px;
    height: 12px;
  }
`;

const LabelStyled = styled(motion.label)<RadioInputProps>`
  font-size: 16px;
  line-height: 1.5;
  letter-spacing: -0.3px;
  color: ${({ isActive, activeColor, defaultColor }) => (isActive ? activeColor : defaultColor)};
  font-family: ${({ isActive }) => (isActive ? theme.fontFamily.bold : theme.fontFamily.normal)};
`;

const VisuallyHiddenRadio = styled.input`
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  border: 0;
`;
