import { ReactNode } from 'react';
import styled from 'styled-components';
import { addPropertyControls, ControlType, PropertyControls } from 'framer';
import { motion } from 'framer-motion';
import { produce } from 'immer';
import theme from '../../../../theme';
import { Title, Paragraph } from '../../atoms';
import { ParagraphProps } from '../../atoms/Paragraph/Paragraph';
import { TitleProps } from '../../atoms/Title/Title';
import { Button } from '../../molecules';
import { ButtonProps } from '../../molecules/Button/Button';
import { Stack } from '../../../layout';

export interface Hero2Props {
  subTitle: TitleProps;
  title: TitleProps;
  description: ParagraphProps;
  buttons: ButtonProps[];
  backgroundImage?: string;
  padding?: { top?: number; bottom?: number; left?: number; right?: number };
  isMobile?: boolean;
  isCenter?: boolean;
}

export default function Hero2(props: Hero2Props) {
  const { subTitle, title, description, buttons, backgroundImage, padding, isMobile, isCenter } = props;

  return (
    <Box url={backgroundImage}>
      <ContentBox isMobile={isMobile} padding={padding}>
        <Title {...subTitle} isMobile={isMobile} />
        <Title {...title} margin="4px 0 0" isMobile={isMobile} />
        <Paragraph {...description} margin="32px 0 0" isMobile={isMobile} />
        <Stack gap={10} justifyContent="center" margin="56px 0 0">
          {buttons?.map((button, index) => {
            return <Button key={index} {...button} />;
          })}
        </Stack>
      </ContentBox>
    </Box>
  );
}

Hero2.defaultProps = {
  subTitle: produce(Title.defaultProps, draft => {
    draft.content = "This is Hero2's SubTitle";
    draft.size = 'md';
    draft.textAlign = 'center';
    draft.fontWeight = 'normal';
  }),
  title: produce(Title.defaultProps, draft => {
    draft.content = '이것은 Hero2의 타이틀\n개행처리도 잘 됩니다';
    draft.size = 'xl';
    draft.textAlign = 'center';
    draft.highlight.color = theme.colors.gray500;
    draft.highlight.height = 36;
    draft.highlight.isVisible = true;
  }),
  description: produce(Paragraph.defaultProps, draft => {
    draft.textAlign = 'center';
    draft.content = 'Body 입력 Body 입력 무엇을 구하지 꽃이 무엇이 천고에 천자만홍이 황금시대다.\n피는 대한 따뜻한 꽃 가슴이 봄바람이다. 속에서 밥을 끓는 속잎나고.';
  }),
  padding: { top: 246, bottom: 246, left: 192, right: 192, isApply: false },
  buttons: Array(1).fill({ ...Button.defaultProps, content: '버튼1', icon: 'chevron-right', iconPosition: 'right' }),
  backgroundImage: '',
  isMobile: false,
};

const Box = styled(motion.div)<any>`
  width: 100%;
  background: url(${props => props.url}) no-repeat;
  background-size: cover;
`;

const ContentBox = styled(motion.div)<any>`
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: ${props => (props.isMobile ? '100px 16px' : `246px 192px`)};
  padding-top: ${({ padding, isApply }) => isApply && padding?.top}px;
  padding-bottom: ${({ padding, isApply }) => isApply && padding?.bottom}px;
  padding-left: ${({ padding, isApply }) => isApply && padding?.left}px;
  padding-right: ${({ padding, isApply }) => isApply && padding?.right}px;
`;
