import styled from 'styled-components';
import { ReactNode } from 'react';

interface StackProps {
  direction: 'row' | 'column' | 'row-reverse';
  gap?: number;
  children: ReactNode;
  justifyContent?: 'flex-start' | 'center' | 'flex-end' | 'space-between';
  alignItems?: 'flex-start' | 'center' | 'flex-end' | 'space-between';
  onClick?: any;
  margin?: string;
  padding?: string;
  width?: string;
  flexWrap?: 'nowrap' | 'wrap' | 'wrap-reverse';
}

export default function Stack(props: StackProps) {
  const { children } = props;

  return <Box {...props}>{children}</Box>;
}

Stack.defaultProps = {
  children: <div style={{ background: 'red', width: '50px', height: '50px' }}>1</div>,
  direction: 'row',
  gap: 24,
  alignItems: 'flex-start',
  onClick: console.log,
  width: '100%',
  flexWrap: 'nowrap',
};

const Box = styled.div<StackProps>`
  display: flex;
  width: ${props => props.width};
  flex-direction: ${props => props.direction};
  gap: ${props => props.gap}px;
  justify-content: ${props => props.justifyContent};
  align-items: ${props => props.alignItems};
  margin: ${props => props.margin};
  padding: ${props => props.padding};
  flex-wrap: ${props => props.flexWrap};
`;
