import { useNavigate, useLocation } from 'react-router-dom';
import { useCallback, useEffect } from 'react';

const useGoogleAnalytics = () => {
  const GA_TRACKING_ID = 'G-D1G3WX8PRT';
  const location = useLocation();

  const pageview = useCallback(url => {
    (window as any).gtag('config', GA_TRACKING_ID, {
      page_path: url,
    });
  }, []);

  const event = useCallback(({ action, category, label, value }: { action: string; category?: string; label?: string; value?: string }) => {
    (window as any).gtag('event', action, {
      event_category: category,
      event_label: label,
      value: value,
    });
  }, []);

  useEffect(() => {
    const isInitialized = typeof (window as any).ga === 'function';
    if (isInitialized) return; // 딱 한번만 초기화

    pageview(location.pathname);
  }, [location, pageview]);

  return { GA_TRACKING_ID, pageview, event };
};

export default useGoogleAnalytics;
